/**
 * Copyright (C) 2023 Chris Noxz
 * Author(s): Chris Noxz <chris@noxz.tech>
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <https://www.gnu.org/licenses/>.
 */

#ifndef CONFIG_H
#define CONFIG_H

static Config cfg[LastConfig] = {
	/* config name              enviornment variable name                       webkit web view setting name                config type invert       default value */
	[AcceptedLanguages]     = { __NAME_UPPERCASE__"_ACCEPTED_LANGUAGES",        NULL,                                       CFG_LIST,   FALSE, {.l = NULL }},
	[BadTlsTabFormat]       = { NULL,                                           NULL,                                       CFG_STRING, FALSE, {.s = "<span foreground=\"yellow\" style=\"italic\">%s</span>" }},
	[ConsoleToStdout]       = { __NAME_UPPERCASE__"_ENABLE_CONSOLE_TO_STDOUT",  "enable-write-console-messages-to-stdout",  CFG_BOOL,   FALSE, {.b = FALSE }},
	[CookieFile]            = { __NAME_UPPERCASE__"_COOKIE_FILE",               NULL,                                       CFG_STRING, FALSE, {.s = NULL }},
	[DnsPrefetching]        = { NULL,                                           "enable-dns-prefetching",                   CFG_BOOL,   FALSE, {.b = FALSE }},
	[DefaultCharset]        = { __NAME_UPPERCASE__"_CHARSET",                   "default-charset",                          CFG_STRING, FALSE, {.s = "UTF-8" }},
	[DefaultFontSize]       = { __NAME_UPPERCASE__"_DEFAULT_FONT_SIZE",         "default-font-size",                        CFG_INT,    FALSE, {.i = 12 }},
	[DefaultFont]           = { __NAME_UPPERCASE__"_DEFAULT_FONT",              "default-font-family",                      CFG_STRING, FALSE, {.s = "monospace" }},
	[DeveloperExtras]       = { NULL,                                           "enable-developer-extras",                  CFG_BOOL,   FALSE, {.b = TRUE }},
	[DisableAutoLoadImages] = { __NAME_UPPERCASE__"_DISABLE_AUTO_LOAD_IMAGES",  "auto-load-images",                         CFG_BOOL,   TRUE,  {.b = FALSE }},
	[DisableJavaScript]     = { __NAME_UPPERCASE__"_DISABLE_JAVASCRIPT",        "enable-javascript-markup",                 CFG_BOOL,   TRUE,  {.b = FALSE }},
	[DownloadDirectory]     = { __NAME_UPPERCASE__"_DOWNLOAD_DIR",              NULL,                                       CFG_STRING, FALSE, {.s = "/var/tmp" }},
	[EncryptedMedia]        = { NULL,                                           "enable-encrypted-media",                   CFG_BOOL,   FALSE, {.b = FALSE }},
	[ExternalHandlerFile]   = { NULL,                                           NULL,                                       CFG_STRING, FALSE, {.s = "exthandler" }},
	[ExternalHandlerKeys]   = { __NAME_UPPERCASE__"_EXTERNAL_HANDLER_KEYS",     NULL,                                       CFG_LIST,   FALSE, {.l = NULL }},
	[FifoName]              = { __NAME_UPPERCASE__"_FIFO_NAME",                 NULL,                                       CFG_STRING, FALSE, {.s = "default" }},
	[HistoryFile]           = { __NAME_UPPERCASE__"_HISTORY_FILE",              NULL,                                       CFG_STRING, FALSE, {.s = NULL }},
	[HomeUri]               = { __NAME_UPPERCASE__"_HOME_URI",                  NULL,                                       CFG_STRING, FALSE, {.s = "about:blank" }},
	[HyperlinkAuditing]     = { NULL,                                           "enable-hyperlink-auditing",                CFG_BOOL,   FALSE, {.b = FALSE }},
	[JsAccessClipboard]     = { NULL,                                           "javascript-can-access-clipboard",          CFG_BOOL,   FALSE, {.b = FALSE }},
	[JsOpenWindows]         = { NULL,                                           "javascript-can-access-clipboard",          CFG_BOOL,   FALSE, {.b = FALSE }},
	[MonospaceFont]         = { __NAME_UPPERCASE__"_MONOSPACE_FONT",            "monospace-font-family",                    CFG_STRING, FALSE, {.s = "monospace" }},
	[NormalTabFormat]       = { NULL,                                           NULL,                                       CFG_STRING, FALSE, {.s = "<span>%s</span>" }},
	[ProxyIgnore]           = { __NAME_UPPERCASE__"_PROXY_IGNORE",              NULL,                                       CFG_LIST,   FALSE, {.l = NULL }},
	[ProxyUri]              = { __NAME_UPPERCASE__"_PROXY_URI",                 NULL,                                       CFG_STRING, FALSE, {.s = NULL }},
	[SansSerifFont]         = { __NAME_UPPERCASE__"_SANS_SERIF_FONT",           "sans-serif-font-family",                   CFG_STRING, FALSE, {.s = "sans-serif" }},
	[SearchEngineUriFormat] = { __NAME_UPPERCASE__"_SE_URI_FORMAT",             NULL,                                       CFG_STRING, FALSE, {.s = "https://ddg.gg?q=%s" }},
	[SerifFont]             = { __NAME_UPPERCASE__"_SERIF_FONT",                "serif-font-family",                        CFG_STRING, FALSE, {.s = "serif" }},
	[SmoothScrolling]       = { __NAME_UPPERCASE__"_ENABLE_SMOOTH_SCROLLING",   "enable-smooth-scrolling",                  CFG_BOOL,   FALSE, {.b = FALSE }},
	[StateFile]             = { __NAME_UPPERCASE__"_STATE_FILE",                NULL,                                       CFG_STRING, FALSE, {.s = NULL }},
	[UcDir]                 = { NULL,                                           NULL,                                       CFG_STRING, FALSE, {.s = "styles" }},
	[UriSchemes]            = { NULL,                                           NULL,                                       CFG_LIST,   FALSE, {.l = (gchar*[]){ "http", "https", "file", "about", "data", "webkit", NULL } }},
	[UsDir]                 = { NULL,                                           NULL,                                       CFG_STRING, FALSE, {.s = "scripts" }},
	[UserAgent]             = { __NAME_UPPERCASE__"_USER_AGENT",                "user-agent",                               CFG_STRING, FALSE, {.s = NULL }},
	[WeDir]                 = { NULL,                                           NULL,                                       CFG_STRING, FALSE, {.s = "web_extensions" }},
	[WebRtc]                = { NULL,                                           "enable-webrtc",                            CFG_BOOL,   FALSE, {.b = FALSE }},
	[XdgSchemes]            = { __NAME_UPPERCASE__"_XDG_SCHEMES",               NULL,                                       CFG_LIST,   FALSE, {.l = NULL }},
	[ZoomLevel]             = { __NAME_UPPERCASE__"_ZOOM_LEVEL",                NULL,                                       CFG_FLOAT,  FALSE, {.f = 1.0 }},
};

#endif /* !CONFIG_H */
